@@ -2,7 +2,7 @@
 #
 #  Net::Server::Daemonize - bdpf - Daemonization utilities.
 #  
-#  $Id: Daemonize.pm,v 1.6 2001/08/24 16:31:44 rhandom Exp $
+#  $Id: Daemonize.pm,v 1.7 2002/09/24 18:55:15 rhandom Exp $
 #  
 #  Copyright (C) 2001, Jeremy Howard
 #                      j+daemonize@howard.fm
@@ -203,7 +203,11 @@ sub set_uid {
   if( $< != $uid ){
     die "Couldn't become uid \"$uid\"\n";
   }
-  POSIX::setuid( $uid ) || die "Couldn't POSIX::setuid to \"$uid\" [$!]\n";
+  my $result = POSIX::setuid( $uid );
+  if( ! defined($result)
+      || $result != $uid ){ # assuming this is true for all systems
+    die "Couldn't POSIX::setuid to \"$uid\" [$!]\n";
+  }
   return 1;
 }
 
